/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.map.google.maps.internal.display.context;

import com.liferay.map.constants.MapProviderWebKeys;
import com.liferay.portal.kernel.model.Group;
import com.liferay.portal.kernel.theme.ThemeDisplay;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.PrefsPropsUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.kernel.util.WebKeys;

import javax.portlet.PortletPreferences;

import javax.servlet.http.HttpServletRequest;

/**
 * @author Jürgen Kappler
 */
public class GoogleMapsDisplayContext {

	public GoogleMapsDisplayContext(HttpServletRequest request) {
		_request = request;
	}

	public String getCompanyGoogleMapsAPIKey() {
		ThemeDisplay themeDisplay = (ThemeDisplay)_request.getAttribute(
			WebKeys.THEME_DISPLAY);

		PortletPreferences companyPortletPreferences =
			PrefsPropsUtil.getPreferences(themeDisplay.getCompanyId());

		return companyPortletPreferences.getValue("googleMapsAPIKey", null);
	}

	public String getConfigurationPrefix() {
		if (Validator.isNull(_configurationPrefix)) {
			_configurationPrefix = GetterUtil.getString(
				_request.getAttribute(
					MapProviderWebKeys.MAP_PROVIDER_CONFIGURATION_PREFIX),
				"TypeSettingsProperties");
		}

		return _configurationPrefix;
	}

	public String getGoogleMapsAPIKey() {
		if (_googleMapsAPIKey != null) {
			return _googleMapsAPIKey;
		}

		Group group = getGroup();

		if (group == null) {
			_googleMapsAPIKey = getCompanyGoogleMapsAPIKey();

			return _googleMapsAPIKey;
		}

		_googleMapsAPIKey = GetterUtil.getString(
			group.getTypeSettingsProperty("googleMapsAPIKey"),
			getCompanyGoogleMapsAPIKey());

		return _googleMapsAPIKey;
	}

	protected Group getGroup() {
		Group group = (Group)_request.getAttribute("site.liveGroup");

		if (group != null) {
			return group;
		}

		ThemeDisplay themeDisplay = (ThemeDisplay)_request.getAttribute(
			WebKeys.THEME_DISPLAY);

		group = themeDisplay.getScopeGroup();

		if (!group.isControlPanel()) {
			return group;
		}

		return null;
	}

	private String _configurationPrefix;
	private String _googleMapsAPIKey;
	private final HttpServletRequest _request;

}